package com.doc.biz.controller;

import com.doc.biz.domain.DocShare;
import com.doc.biz.service.IDocShareService;
import com.doc.chat.domain.ChatMsg;
import com.doc.chat.service.IChatMsgService;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.utils.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文档分享Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文档分享")
@RestController
@RequestMapping("/biz/share")
public class DocShareController extends BaseController {
    @Resource
    private IDocShareService docShareService;
    @Resource
    private IChatMsgService msgService;

    /**
     * 文件分享
     */
    @ApiOperation("获取已选择人员")
    @GetMapping("/{docId}")
    public List<DocShare> shareInfo(@ApiParam(value = "文件ID", required = true) @PathVariable(name = "docId") Long docId) {
        return docShareService.selectDocShareListByDocId(docId);
    }

    /**
     * 文件分享
     */
    @ApiOperation("添加人员")
    @PostMapping("/{docId}")
    public AjaxResult share(@ApiParam(value = "文件ID", required = true) @PathVariable(name = "docId") Long docId, @ApiParam(value = "分享人员", required = true) @RequestBody List<Long> users) {
        docShareService.deleteDocShareByDocId(docId);
        users.forEach(uid -> {
            //发送消息
            ChatMsg msg = new ChatMsg();
            msg.setMsgType("1");
            msg.setToId(uid);
            msg.setContent(docId + "");
            msg.setFromId(SecurityUtils.getUserId());
            msgService.send(msg);

            //添加人员
            DocShare share = new DocShare();
            share.setDocId(docId);
            share.setUserId(uid);
            docShareService.insertDocShare(share);
        });

        return success();
    }
//
//    /**
//     * 查询文档分享列表
//     */
////    @ApiOperation("查询文档分享列表")
//    //@PreAuthorize("@ss.hasPermi('biz:share:list')")
//    @GetMapping("/list")
//    public TableDataInfo list(DocShare docShare) {
//        startPage();
//        List<DocShare> list = docShareService.selectDocShareList(docShare);
//        return getDataTable(list);
//    }
//
//    /**
//     * 导出文档分享列表
//     */
////    @ApiOperation("导出文档分享列表")
//    //@PreAuthorize("@ss.hasPermi('biz:share:export')")
//    @Log(title = "文档分享", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, DocShare docShare) {
//        List<DocShare> list = docShareService.selectDocShareList(docShare);
//        ExcelUtil<DocShare> util = new ExcelUtil<DocShare>(DocShare.class);
//        util.exportExcel(response, list, "文档分享数据");
//    }
//
//    /**
//     * 获取文档分享详细信息
//     */
////    @ApiOperation("获取文档分享详细信息")
//    //@PreAuthorize("@ss.hasPermi('biz:share:query')")
//    @GetMapping(value = "/{shareId}")
//    public AjaxResult getInfo(@PathVariable("shareId") Long shareId) {
//        return success(docShareService.selectDocShareByShareId(shareId));
//    }
//
//    /**
//     * 新增文档分享
//     */
////    @ApiOperation("新增文档分享")
//    //@PreAuthorize("@ss.hasPermi('biz:share:add')")
//    @Log(title = "文档分享", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody DocShare docShare) {
//        return toAjax(docShareService.insertDocShare(docShare));
//    }
//
//    /**
//     * 修改文档分享
//     */
////    @ApiOperation("修改文档分享")
//    //@PreAuthorize("@ss.hasPermi('biz:share:edit')")
//    @Log(title = "文档分享", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody DocShare docShare) {
//        return toAjax(docShareService.updateDocShare(docShare));
//    }
//
//    /**
//     * 删除文档分享
//     */
////    @ApiOperation("删除文档分享")
//    //@PreAuthorize("@ss.hasPermi('biz:share:remove')")
//    @Log(title = "文档分享", businessType = BusinessType.DELETE)
//    @DeleteMapping("/{shareIds}")
//    public AjaxResult remove(@PathVariable Long[] shareIds) {
//        return toAjax(docShareService.deleteDocShareByShareIds(shareIds));
//    }
}
