package com.doc.biz.controller;

import com.doc.biz.domain.DocSpace;
import com.doc.biz.domain.DocSpaceExpansion;
import com.doc.biz.service.IDocSpaceExpansionService;
import com.doc.biz.service.IDocSpaceService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 空间扩容管理Controller
 *
 * @author wukai
 * @date 2023-09-20
 */
@Api(tags = "空间扩容管理")
@RestController
@RequestMapping("/biz/expansion")
public class DocSpaceExpansionController extends BaseController {
    @Resource
    private IDocSpaceExpansionService docSpaceExpansionService;

    @Resource
    private IDocSpaceService spaceService;

    /**
     * 查询空间扩容管理列表
     */
    @ApiOperation("查询空间扩容管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:expansion:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocSpaceExpansion docSpaceExpansion) {
        startPage();
        List<DocSpaceExpansion> list = docSpaceExpansionService.selectDocSpaceExpansionList(docSpaceExpansion);
        return getDataTable(list);
    }

    /**
     * 新增空间扩容管理
     */
    @ApiOperation("申请扩容")
    @Log(title = "空间扩容管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult apply(@RequestBody DocSpaceExpansion docSpaceExpansion) {
        DocSpace space = spaceService.selectDocSpaceBySpaceId(docSpaceExpansion.getSpaceId());
        docSpaceExpansion.setExpandStatus("1");
        docSpaceExpansion.setSpaceName(space.getSpaceName());
        docSpaceExpansion.setCurrentCap(space.getSpaceCap());
        return toAjax(docSpaceExpansionService.insertDocSpaceExpansion(docSpaceExpansion));
    }

    @ApiOperation("同意扩容")
    @Log(title = "空间扩容管理", businessType = BusinessType.UPDATE)
    @PostMapping("/agree/{autoId}")
    public AjaxResult agree(@PathVariable("autoId") Long autoId) {
        DocSpaceExpansion expansion = docSpaceExpansionService.selectDocSpaceExpansionByAutoId(autoId);
        expansion.setExpandStatus("2");

        spaceService.addCap(expansion.getSpaceId(), expansion.getExpandCap());

        return success(docSpaceExpansionService.updateDocSpaceExpansion(expansion));
    }

    @ApiOperation("拒绝扩容")
    @Log(title = "空间扩容管理", businessType = BusinessType.UPDATE)
    @PostMapping("/refuse/{autoId}")
    public AjaxResult refuse(@PathVariable("autoId") Long autoId, @RequestParam String remark) {
        DocSpaceExpansion expansion = docSpaceExpansionService.selectDocSpaceExpansionByAutoId(autoId);
        expansion.setExpandStatus("3");
        expansion.setDescription(remark);
        return success(docSpaceExpansionService.updateDocSpaceExpansion(expansion));
    }
}
