package com.doc.biz.ws;

import com.doc.chat.domain.ChatMsg;
import com.doc.common.utils.StringUtils;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.connection.Message;
import org.springframework.data.redis.connection.MessageListener;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.serializer.RedisSerializer;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * 集群聊天消息监听器
 *
 * @author wukai
 * @date 2023/8/23 17:52
 */

@Component
@Slf4j
public class ChatMessageListener implements MessageListener {

    @Resource
    private RedisTemplate redisTemplate;

    @Resource
    private WebSocketServer websocketEndpoint;

    @Override
    public void onMessage(Message message, byte[] pattern) {
        RedisSerializer<String> valueSerializer = redisTemplate.getStringSerializer();
        String value = valueSerializer.deserialize(message.getBody());

        if (StringUtils.isNotBlank(value)) {
            System.err.println(value);
            log.info("监听集群websocket消息--- {}", value);
            //集群模式 推送消息
            ObjectMapper mapper = new ObjectMapper();
            ChatMsg msg;
            try {
                msg = mapper.readValue(value, ChatMsg.class);
            } catch (JsonProcessingException e) {
                throw new RuntimeException(e);
            }
            websocketEndpoint.sendClusterWebsocketMessage(msg);
        }
    }

}

